@@ -137,7 +137,7 @@ def get_parser():
     parser.add_argument("-f", "--features",
                         dest="analyze_features",
                         help="analyze features",
-                        type="store_true",
+                        action="store_true",
                         default=False)
     return parser
 
