@@ -418,7 +418,7 @@ def create_pfile(output_filename, feature_count, data):
     #f = tempfile.NamedTemporaryFile()
     #input_filename = f.name
     input_filename = "tmp.pfile"
-    f = open(input_filename)
+    f = open(input_filename, "w")
 
     for symbolnr, instance in enumerate(data):
         feature_string, label = instance
